package net.wanji.common.utils.mail;

import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.common.utils.tool.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.mail.SimpleMailMessage;
import org.springframework.mail.javamail.JavaMailSenderImpl;

import javax.mail.Session;
import java.util.Map;
import java.util.Properties;

/**
 * @ClassName MailUtils
 * @Description 邮件工具类
 * @Author wanji
 * @Date 2020/5/29 13:44
 * @Version 1.0
 */
@Slf4j
public class MailUtils {

    /**
     * @return void
     * @throws
     * @Author wanji
     * @Description 邮件发送
     * @Date 13:57 2020/5/29
     * @Param [m2AMail, map]
     */
    public static JsonViewObject sendSimpleMail(Map<String, Object> map) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        // 发送器
        JavaMailSenderImpl sender = new JavaMailSenderImpl();
        try {
            sender.setHost((String) map.get("server"));
            sender.setPort(Integer.parseInt(map.get("port").toString()));
            sender.setUsername((String) map.get("user"));
            sender.setPassword((String) map.get("pwd"));
        } catch (Exception e) {
            log.error("邮件发送器装配异常", e);
            return jsonViewObject.fail("邮件发送器装配异常");
        }
        // 配置文件对象
        try {
            Properties props = new Properties();
            props.put("mail.smtp.auth", map.get("ssl")); // 是否进行验证
            Session session = Session.getInstance(props);
            sender.setSession(session); // 为发送器指定会话
        } catch (Exception e) {
            log.error("文件对象装配异常", e);
            return jsonViewObject.fail("文件对象装配异常");
        }
        SimpleMailMessage mail = new SimpleMailMessage();
        try {
            String addressee = String.valueOf(map.get("addressee")); // 收件人
            String[] split = addressee.split(";");
            mail.setTo(split);
            //todo 完善抄送，密送
            mail.setSubject(String.valueOf(map.get("title"))); // 标题
            String senderMailAddr = (String) map.get("defaultSender");
            if (map.containsKey("sender") && StringUtils.isNotBlank((String) map.get("sender"))) {
                senderMailAddr = String.valueOf(map.get("sender"));
            }
            mail.setFrom(senderMailAddr); // 发件人
            mail.setText(String.valueOf(map.get("message"))); // 邮件内容
        } catch (Exception e) {
            log.error("邮件信息装配异常", e);
            return jsonViewObject.fail("邮件信息装配异常");
        }
        try {
            sender.send(mail); // 发送
            log.info("邮件发送成功");
            jsonViewObject.success("邮件发送成功");
        } catch (Exception e) {
            log.error("邮件发送异常", e);
            jsonViewObject.fail("邮件发送异常");
        }
        return jsonViewObject;
    }
}
